# v0.27.x series (next stable)

## v0.27.0 (upcoming release)

### Deprecated

* ⚠️ Specifying the spectral range for atmospheric absorption database
  configuration is no longer required. The previous behaviour is removed and
  the corresponding interface is deprecated.

### Removed

* ⚠️ Specifying atmospheric absorption databases using loaded data is no longer
  supported. Instead, instantiate an {class}`.AbsorptionDatabase` object.

### Added

* Introduced a new {class}`.AbsorptionDatabase` abstraction in charge of
  managing atmospheric molecular absorption data ({ghpr}`397`).
* Eradiate can now be configured using TOML files ({ghpr}`397`).
* The `eradiate data fetch` command-line interface now accepts keywords to
  facilitate absorption database downloads ({ghpr}`397`).
* Gaussian SRF datasets can now be dynamically generated using the
  :func:`.srf_tools.make_gaussian` function ({ghpr}`401`).
* All `.Shape` classes now support a `to_world` member, which defines an
  arbitrary transformation of the object ({ghpr}`381`).
* The eradiate data fetch command is extended with the possibility to fetch
  groups of files (*e.g.* `eradiate data fetch monotropa`) ({ghpr}`405`).

### Changed

* ⚠️ Most settings are now accessed through the :attr:`.settings` mapping
  ({ghpr}`397`).
* 📖 The Data documentation content is extracted from the user guide and moved
  to its own section ({ghpr}`405`).

### Fixed

* Large absorption databases are now handled with little to no performance
  penalty ({ghpr}`397`).
* DEM Surfaces would not behave correctly when used with a
  {class}`.SphericalShellGeometry` ({ghpr}`402`).
* CKD bin selection no longer crashes if theoretically identical min and max
  bounds of two adjacent bins have an actual mismatch due to floating point
  precision issues ({ghpr}`406`).
* The SRF weighting operation is removed from monochromatic post-processing
  pipelines ({ghpr}`406`).

### Internal changes

* 🖥️ Settings are now powered by the Dynaconf library ({ghpr}`397`).
* 🖥️ Renamed and refactored atmosphere fixtures for performance and clarity
  ({ghpr}`397`).
* 🖥️ Reorganized test code and fixtures for clarity ({ghpr}`399`).
